@@ -1,4 +1,5 @@
 from configparser import ConfigParser
+import re
 
 class Config:
 
@@ -16,17 +17,13 @@ class Config:
         if section in self.config and key in self.config[section]:
             response = self.config[section][key]
 
-            if response == 'True':
-                return True
-            elif response == 'False':
-                return False
-            else:
-                return response
+            if response == 'True': return True
+            elif response == 'False': return False
+            elif bool(re.search('^(?=.)([+-]?([0-9]*)(\.([0-9]+))?)$', response)) is True and '.' in response: return float(response)
+            elif bool(re.search('^(?=.)([+-]?([0-9]*)(\.([0-9]+))?)$', response)) is True and '.' not in response: return int(response)
+            else: return response
 
         elif (section in self.config and key not in self.config[section]) or (section not in self.config):
-            if default is not None:
-                return default
-            else:
-                return None
-        else:
-            raise Exception('Configuration not found!')
\ No newline at end of file
+            if default is not None: return default
+            else: return None
+        else: raise Exception('Configuration not found!')
\ No newline at end of file
